==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/DeviceFarm/GetJob.pm <==

package Paws::DeviceFarm::GetJob;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'arn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DeviceFarm::GetJobResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetJob - Arguments for method GetJob on L<Paws::DeviceFarm>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetJob on the
L<AWS Device Farm|Paws::DeviceFarm> service. Use the attributes of this class
as arguments to method GetJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetJob.

=head1 SYNOPSIS

    my $devicefarm = Paws->service('DeviceFarm');
    # To get information about a job
    # The following example returns information about a specific job.
    my $GetJobResult = $devicefarm->GetJob(
      {
        'Arn' => 'arn:aws:devicefarm:us-west-2::job:123-456-EXAMPLE-GUID'
      }
    );

    # Results:
    my $job = $GetJobResult->job;

    # Returns a L<Paws::DeviceFarm::GetJobResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/devicefarm/GetJob>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Arn => Str

The job's ARN.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetJob in L<Paws::DeviceFarm>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/DeviceFarm/GetJob.pm <==

package Paws::DeviceFarm::GetJob;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'arn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetJob');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::DeviceFarm::GetJobResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DeviceFarm::GetJob - Arguments for method GetJob on L<Paws::DeviceFarm>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetJob on the
L<AWS Device Farm|Paws::DeviceFarm> service. Use the attributes of this class
as arguments to method GetJob.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetJob.

=head1 SYNOPSIS

    my $devicefarm = Paws->service('DeviceFarm');
    # To get information about a job
    # The following example returns information about a specific job.
    my $GetJobResult = $devicefarm->GetJob(
      'Arn' => 'arn:aws:devicefarm:us-west-2::job:123-456-EXAMPLE-GUID' );

    # Results:
    my $job = $GetJobResult->job;

    # Returns a L<Paws::DeviceFarm::GetJobResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/devicefarm/GetJob>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Arn => Str

The job's ARN.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetJob in L<Paws::DeviceFarm>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
